/*
Copyright (c) 1998-2009 VIA Technologies, Inc. All Rights Reserved.
 
This PROPRIETARY SOURCE CODE contains proprietary information of VIA 
Technologies, Inc. (VIA); Contents of this file shall not be disclosed to any 3rd party, 
copied or duplicated in any form, in whole or in part without prior written consent of 
VIA.  THIS SOURCE CODE & ANY RELATED DOCUMENTATION 
(COLLECTIVELY SOFTWARE) ARE PROVIDED AS IS, WITH ALL FAULTS, & 
WITHOUT WARRANTY OF ANY KIND.  VIA DISCLAIMS ALL EXPRESS OR 
IMPLIED WARRANTIES.  USER ACKNOWLEDGES THAT PARTIES FOR ANY 
DAMAGES ARISING FROM USE OF SOFTWARE OR ITS DERIVATIVE, 
INCLUDING, W/O LIMITATION, LOSS OF USE, DATA OR PROFITS. USER
WHOLLY ASSUMES ALL RISK ARISING FROM USE & PERFORMANCE OF 
SOFTWARE
*/ 
 
#ifndef ETKAPI_GPIO_H_
#define ETKAPI_GPIO_H_

#include "etkapi_base.h"

#ifdef __cplusplus
extern "C" {
#endif

/************************************************************************
		GPIO
************************************************************************/

#pragma pack(1)
/**
 * The structure can be used to get GPIO information from the motherboard driver.
 *
 */
typedef struct
{
	BYTE	nGPINum;           ///< number of GPI
	BYTE	nGPONum;           ///< number of GPO
	BYTE	auGPIList[32];     ///< a list of GPI pin id
	BYTE	auGPOList[32];     ///< a list of GPO pin id
} TETKGpioInfo, *PTETKGpioInfo;

#pragma pack()

/**
 * The board supports GPIO function or not
 * @return   : Returns TRUE if support or FALSE otherwise.
 */
SMARTETK_API BOOL ETKSdk_SupportGpio(void);

/**
 * Get the value of GPI pin
 * @param byPinID: Which GPI pin will be got. The valid pin id can be got from ETKGpio_GetInfo()
 * @param pbyValue: a pointer to that receives the SPI value from the driver. The value is only 0 or 1.
 * @return   : Returns ETK_S_OK if successful or ETK_E_FAIL otherwise.
 */
SMARTETK_API DWORD ETKGpio_Read(BYTE byPinID, BYTE * pbyValue);

/**
 * Set the value to GPO pin
 * @param byPinID: Which GPO pin will be set. The valid pin id can be got from ETKGpio_GetInfo()
 * @param byValue: the value will be set to GPO, The value is only 0 or 1.
 * @return   : Returns ETK_S_OK if successful or ETK_E_FAIL otherwise.
 */
SMARTETK_API DWORD ETKGpio_Write(BYTE byPinID, BYTE byValue);

/**
 * Get the number of GPI and GPO and which pins can be set/got.
 * @param ptGpioInfo: a pointer to a structure of TGpioInfo that includes GPIO information.
 * @return   : Returns ETK_S_OK if successful or ETK_E_FAIL otherwise.
 */
SMARTETK_API DWORD ETKGpio_GetInfo(PTETKGpioInfo ptGpioInfo);


#ifdef __cplusplus
} // extern C
#endif

#endif
